@@ -159,9 +159,6 @@ class Connection(object):
 
 
 class OvsdbIdl(idl.Idl):
-    def cooperative_yield(self):
-        time.sleep(0)
-
     @classmethod
     def from_server(cls, connection_string, schema_name):
         """Create the Idl instance by pulling the schema from OVSDB server"""
@@ -195,29 +192,13 @@ class OvsdbIdl(idl.Idl):
 
         schema = schema_helper.get_idl_schema()
         self._db = schema
-        removed = self.tables.keys() - schema.tables.keys()
-        added = schema.tables.keys() - self.tables.keys()
-
-        # stop monitoring removed tables
-        for table in removed:
-            self.cond_change(table, [False])
-            del self.tables[table]
-
-        try:
-            _tables = idl.IdlTable.schema_tables(self, schema)
-        except AttributeError:
-            _tables = None
-        # add new tables as Idl.__init__ does
-        for table in (schema.tables[table] for table in added):
-            self.tables[table.name] = _tables[table.name] if _tables else table
+        self.tables = schema.tables
+        for table in schema.tables.values():
             for column in table.columns.values():
                 if not hasattr(column, 'alert'):
                     column.alert = True
             table.need_table = False
             table.rows = custom_index.IndexedRows(table)
             table.idl = self
-            try:
-                table.condition = idl.ConditionState()
-            except AttributeError:
-                table.condition = [True]
+            table.condition = [True]
             table.cond_changed = False
